translate.misc.multistring.multistring

Package translate :: Package misc :: Module multistring :: Class multistring |
[hide private]
[frames] | no frames]

# Class multistring

source code

Instance Methods | [hide private]
__init__(self, *args, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__cmp__(self, otherstring) | source code
__ne__(self, otherstring) x!=y | source code
__eq__(self, otherstring) x==y | source code
__repr__(self) repr(x) | source code
replace(self, old, new, count=None) S.replace (old, new[, maxsplit]) -> unicode | source code
Inherited from `autoencode.autoencode`: `__str__`, `join` Inherited from `unicode`: `__add__`, `__contains__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__rmod__`, `__rmul__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `index`, `isalnum`, `isalpha`, `isdecimal`, `isdigit`, `islower`, `isnumeric`, `isspace`, `istitle`, `isupper`, `ljust`, `lower`, `lstrip`, `partition`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Static Methods | [hide private]
a new object with type S, a subtype of T |
__new__(newtype, string=`u'````'`, encoding=None, errors=None) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(newtype, string=`u'````'`, encoding=None, errors=None) Static Method | source code
Returns: a new object with type S, a subtype of T Overrides: object.__new__ (inherited documentation)

### __init__(self, *args, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __ne__(self, otherstring) | source code
x!=y Overrides: unicode.__ne__ (inherited documentation)

### __eq__(self, otherstring) (Equality operator) | source code
x==y Overrides: unicode.__eq__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### replace(self, old, new, count=None) | source code
S.replace (old, new[, maxsplit]) -> unicode Return a copy of S with all occurrences of substring old replaced by new. If the optional argument maxsplit is given, only the first maxsplit occurrences are replaced. Overrides: unicode.replace (inherited documentation)